@@ -500,7 +500,7 @@ update_cache (EBookBackendExchange *be)
 	EContact *contact;
 	const char *cache_file_name;
 	time_t mod_time;
-	char time_string[25];
+	char time_string[50]; /* Donno what could be right. 50 should be safe for sure.*/
 	const struct tm *tm;
 	struct stat buf;
 
@@ -510,7 +510,7 @@ update_cache (EBookBackendExchange *be)
 	stat (cache_file_name, &buf);
 	mod_time = buf.st_mtime;
 	tm = gmtime (&mod_time);
-	strftime (time_string, 100, "%Y-%m-%dT%H:%M:%SZ", tm);
+	strftime (time_string, 50, "%Y-%m-%dT%H:%M:%SZ", tm);
 
 	/* build hash table from storage file */
 
